@@ -1,8 +1,8 @@
 ##' Append one Crunch dataset to another
 ##'
 ##' @param dataset1 a CrunchDataset
-##' @param dataset2 another CrunchDataset, or possibly a data.frame. If 
-##' \code{dataset2} is not a Crunch dataset, it will be uploaded as a new 
+##' @param dataset2 another CrunchDataset, or possibly a data.frame. If
+##' \code{dataset2} is not a Crunch dataset, it will be uploaded as a new
 ##' dataset before appending.
 ##' @param cleanup logical: if the append operation fails or is aborted, should
 ##' the intermediate batch created on \code{dataset1} be deleted? Default is
@@ -11,17 +11,17 @@
 ##' @return A CrunchDataset with \code{dataset2} appended to \code{dataset1}
 ##' @export
 appendDataset <- function (dataset1, dataset2, cleanup=TRUE) {
-    
+
     stopifnot(is.dataset(dataset1))
-    batch_url <- addBatchToDataset(dataset1, dataset2)    
+    batch_url <- addBatchToDataset(dataset1, dataset2)
     dataset <- try(acceptAppendResolutions(batch_url, dataset1), silent=TRUE)
     if (is.error(dataset)) {
         if (cleanup) {
-            d <- try(crDELETE(batch_url, 
+            d <- try(crDELETE(batch_url,
                     drop=dropCache(shojiURL(dataset1, "catalogs", "batches"))),
                 silent=TRUE)
             if (is.error(d)) {
-                warning("Batch ", batch_url, 
+                warning("Batch ", batch_url,
                     " could not be deleted. It may still be processing.")
             }
         } else {
@@ -39,31 +39,29 @@ addBatchToDataset <- function (dataset1, dataset2) {
         message("Creating ", dQuote(temp.ds.name), " as temporary dataset")
         dataset2 <- newDataset(dataset2, name=temp.ds.name)
     }
-    
+
     ## Validate
     if (identical(self(dataset1), self(dataset2))) {
         halt("Cannot append dataset to itself")
     }
-    
+
     batches_url <- shojiURL(dataset1, "catalogs", "batches")
     body <- list(
         element="shoji:entity",
         body=list(
-            dataset=self(dataset2),
-            workflow=I(list()),
-            async=TRUE
+            dataset=self(dataset2)
         )
     )
     invisible(crPOST(batches_url, body=toJSON(body)))
 }
 
 acceptAppendResolutions <- function (batch_url, dataset, ...) {
-    
+
     status <- pollBatchStatus(batch_url, batches(dataset), until=c("ready", "imported"))
-    
+
     batch <- ShojiObject(crGET(batch_url))
     cflicts <- flattenConflicts(batch@body$conflicts)
-    
+
     if (status == "conflict") {
         failures <- formatFailures(cflicts)
         for (i in failures) message(i)
@@ -71,10 +69,10 @@ acceptAppendResolutions <- function (batch_url, dataset, ...) {
             "Please manually address them and retry.")
         halt(paste(err, collapse=" "))
     }
-    
+
     resolutions <- formatConflicts(cflicts)
     ## Report on what was done/will be done
     for (i in resolutions) message(i)
-    
+
     invisible(refresh(dataset))
 }
