@@ -1,15 +1,14 @@
 is.category <- function (x) inherits(x, "Category")
 
-validCategory <- function (object) {
+setValidity("Category", function (object) {
     is.cat <- all(c("id", "name") %in% names(object))
     if (!all(is.cat)) {
         val <- "Not a category"
     } else {
-        val <- TRUE  
+        val <- TRUE
     }
     return(val)
-}
-setValidity("Category", validCategory)
+})
 
 init.Category <- function (.Object, ...) {
     .Object <- callNextMethod()
@@ -44,7 +43,7 @@ setValue <- function (x, value) {
 }
 
 ##' Access Category fields directly
-##' 
+##'
 ##' Don't do this. Instead, use the category setters.
 ##'
 ##' @param x a Category
@@ -67,7 +66,7 @@ setMethod("$<-", "Category", function (x, name, value) {
 })
 
 ##' Category attributes
-##' 
+##'
 ##' @param x a Category
 ##' @param value For the setters, an appropriate value to set
 ##' @return \code{name} returns character; \code{value} and \code{id} return
@@ -112,4 +111,4 @@ setMethod("is.na<-", c("Category", "logical"), function (x, value) {
     stopifnot(length(value) == 1)
     x$missing <- isTRUE(value)
     return(x)
-})
\ No newline at end of file
+})
