@@ -1,7 +1,7 @@
 init.Shoji <- function (.Object, ...) {
     slots <- slotNames(.Object)
     dots <- list(...)
-    ## Different cases are so you can call the class constructor directly 
+    ## Different cases are so you can call the class constructor directly
     ## with different inputs
     if (length(dots) && is.shojiObject(dots[[1]])) {
         ## Init from a parent class, e.g. CrunchObject(ShojiObject(x))
@@ -30,24 +30,11 @@ is.shoji.like <- function (x) {
     is.list(x) && "element" %in% names(x) && substr(as.character(x$element), 1, 5) == "shoji"
 }
 
-is.shoji.order.like <- function (x) {
-    ## Hack. But anticipating Order becoming not a shoji:view
-    is.shoji.like(x) && x$element == "shoji:view" && identical(names(x$value), "groups")
-}
-
 ##' @rdname crunch-is
 ##' @export
 ##' @importFrom methods is
 is.shoji <- function (x) inherits(x, "shoji")
 
-setOldClass("shoji")
-
-setAs("shoji", "ShojiObject", function (from) {
-    cl <- ifelse(from$element == "shoji:catalog", "ShojiCatalog", "ShojiObject")
-    return(do.call(cl, from))
-})
-as.shojiObject <- function (x) as(x, "ShojiObject")
-
 is.shojiObject <- function (x) inherits(x, "ShojiObject")
 
 ##' Get the URL of this object
@@ -77,14 +64,14 @@ setMethod("delete", "ShojiObject", function (x, ...) invisible(crDELETE(self(x))
 ##' @export
 setMethod("delete", "ANY", function (x, ...) halt("'delete' only valid for Crunch objects"))
 
+##' Base setter for Crunch objects
+##' @param x a ShojiObject or subclass thereof
+##' @param i character the slot name to update
+##' @param value whatever the new value of that slot should be
+##' @return x modified accordingly. If \code{x} isn't read-only, it will also
+##' post the edit to the Crunch server.
+##' @keywords internal
 setEntitySlot <- function (x, i, value) {
-    ##' Base setter for Crunch objects
-    ##' @param x a ShojiObject or subclass thereof
-    ##' @param i character the slot name to update
-    ##' @param value whatever the new value of that slot should be
-    ##' @return x modified accordingly. If \code{x} isn't read-only, it will also
-    ##' post the edit to the Crunch server.
-    
     ## Check if we have actual changes to send. Wrap both sides in I()
     ## in case "value" is already wrapped
     if (!identical(I(slot(x, "body")[[i]]), I(value))) {
@@ -106,6 +93,13 @@ setReadonly <- function (x, value) {
 
 setMethod("readonly<-", "ShojiObject", setReadonly)
 
+##' Get a resource URL from a Shoji Object
+##' @param x a shojiObject
+##' @param collection one of c("catalogs", "views", "fragments")
+##' @param key character name of the URL to get from \code{collection}
+##' @return character URL
+##' @export
+##' @keywords internal
 shojiURL <- function (x, collection=c("catalogs", "views", "fragments"), key) {
     if (is.variable(x)) {
         x <- entity(x) ## Get the VariableEntity
@@ -116,5 +110,9 @@ shojiURL <- function (x, collection=c("catalogs", "views", "fragments"), key) {
     }
     collection <- match.arg(collection)
     urls <- slot(x, collection)
-    return(urls[[key]])
+    out <- urls[[key]]
+    if (is.null(out)) {
+        halt("No URL ", dQuote(key), " in collection ", dQuote(collection))
+    }
+    return(out)
 }
