@@ -22,8 +22,9 @@ if (run.integration.tests) {
                     expect_identical(length(batches(part1)), 2L)
                     expect_identical(length(batches(part2)), 2L)
                 })
-                out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("identical datasets with arrays can append", {
+                    expect_message(out <- appendDataset(part1, part2),
+                        "No conflicts")
                     expect_that(out, is_not_an_error())
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 3L)
@@ -36,24 +37,24 @@ if (run.integration.tests) {
                 })
             })
         })
-        
+
         with(test.dataset(mrdf, "part1"), {
             part1 <- mrdf.setup(part1, selections="1.0")
             mr_cats <- categories(part1$MR)
             subvar_cats <- categories(part1$MR$mr_1)
             dichotomized_cats <- Categories(
-                list(id=2L, missing=FALSE, name="0.0", numeric_value=0, selected=FALSE), 
+                list(id=2L, missing=FALSE, name="0.0", numeric_value=0, selected=FALSE),
                 list(id=1L, missing=FALSE, name="1.0", numeric_value=1, selected=TRUE),
                 list(id=-1L, missing=TRUE, name="No Data", numeric_value=NULL, selected=FALSE))
             with(test.dataset(mrdf, "part2"), {
                 ## Dichotomize this way so that categories get aligned
-                ## (via supertype)              
+                ## (via supertype)
                 part2 <- mrdf.setup(part2)
                 unbind(part2$CA)
                 part2 <- refresh(part2)
                 undichotomized_cats <- Categories(
                     list(id=2L, missing=FALSE, name="0.0", numeric_value=0),
-                    list(id=1L, missing=FALSE, name="1.0", numeric_value=1), 
+                    list(id=1L, missing=FALSE, name="1.0", numeric_value=1),
                     list(id=-1L, missing=TRUE, name="No Data", numeric_value=NULL))
                 test_that("set up MR for appending", {
                     expect_true(is.Multiple(part1$MR))
@@ -63,7 +64,7 @@ if (run.integration.tests) {
                     expect_true(is.null(part2$MR))
                     expect_identical(mr_cats, subvar_cats)
                     expect_identical(mr_cats, dichotomized_cats)
-                    expect_identical(categories(part2$mr_1), 
+                    expect_identical(categories(part2$mr_1),
                         undichotomized_cats)
                     expect_false(identical(dichotomized_cats,
                         undichotomized_cats)) ## Just being clear about that
@@ -88,7 +89,7 @@ if (run.integration.tests) {
                     expect_identical(categories(out$MR$mr_1), dichotomized_cats)
                     expect_false(identical(categories(out$MR),
                         undichotomized_cats))
-                    expect_identical(as.vector(out$MR$mr_1), 
+                    expect_identical(as.vector(out$MR$mr_1),
                         rep(as.vector(part2$mr_1), 2))
                     expect_true(is.Multiple(out$MR))
                     expect_identical(names(subvariables(out$MR)),
@@ -104,16 +105,16 @@ if (run.integration.tests) {
             mr_cats <- categories(part1$MR)
             subvar_cats <- categories(part1$MR$mr_1)
             dichotomized_cats <- Categories(
-                list(id=2L, missing=FALSE, name="0.0", numeric_value=0, selected=FALSE), 
+                list(id=2L, missing=FALSE, name="0.0", numeric_value=0, selected=FALSE),
                 list(id=1L, missing=FALSE, name="1.0", numeric_value=1, selected=TRUE),
                 list(id=-1L, missing=TRUE, name="No Data", numeric_value=NULL, selected=FALSE))
-            with(test.dataset(mrdf, "part2"), {                
+            with(test.dataset(mrdf, "part2"), {
                 cast.these <- grep("mr_", names(part2))
                 part2[cast.these] <- lapply(part2[cast.these],
                     castVariable, "categorical")
                 undichotomized_cats <- Categories(
                     list(id=2L, missing=FALSE, name="0.0", numeric_value=0),
-                    list(id=1L, missing=FALSE, name="1.0", numeric_value=1), 
+                    list(id=1L, missing=FALSE, name="1.0", numeric_value=1),
                     list(id=-1L, missing=TRUE, name="No Data", numeric_value=NULL))
                 test_that("set up MR for appending", {
                     expect_true(is.Multiple(part1$MR))
@@ -123,7 +124,7 @@ if (run.integration.tests) {
                     expect_true(is.null(part2$MR))
                     expect_identical(mr_cats, subvar_cats)
                     expect_identical(mr_cats, dichotomized_cats)
-                    expect_identical(categories(part2$mr_1), 
+                    expect_identical(categories(part2$mr_1),
                         undichotomized_cats)
                     expect_identical(as.vector(part1$MR$mr_1),
                         as.vector(part2$mr_1))
@@ -132,8 +133,9 @@ if (run.integration.tests) {
                     expect_identical(as.vector(part1$MR$mr_3),
                         as.vector(part2$mr_3))
                 })
-                out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("unbound subvars with not identical cats", {
+                    expect_message(out <- appendDataset(part1, part2),
+                        "No conflicts")
                     expect_that(out, is_not_an_error())
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 3L)
@@ -144,7 +146,7 @@ if (run.integration.tests) {
                     expect_false(identical(categories(out$MR),
                         undichotomized_cats)) ## To be clear about the problem
                     ## Not handling categories with different ids but same names
-                    expect_identical(as.vector(out$MR$mr_1), 
+                    expect_identical(as.vector(out$MR$mr_1),
                         rep(as.vector(part2$mr_1), 2))
                     expect_true(is.Multiple(out$MR))
                     expect_identical(names(subvariables(out$MR)),
@@ -155,7 +157,7 @@ if (run.integration.tests) {
                 })
             })
         })
-        
+
         with(test.dataset(mrdf[-3], "part1"), {
             part1 <- mrdf.setup(part1, selections="1.0")
             part1 <- saveVersion(part1, "Before appending")
@@ -189,7 +191,7 @@ if (run.integration.tests) {
                         array(c(2, 2, 1), dim=c(3L),
                         dimnames=list(MR=c("mr_1", "mr_2", "mr_3"))))
                 })
-                
+
                 test_that("Rolling back to initial import reverts the append", {
                     out <- restoreVersion(out, "Before appending")
                     expect_true(is.Multiple(out$MR))
@@ -202,7 +204,7 @@ if (run.integration.tests) {
                 })
             })
         })
-        
+
         sparsemrdf1 <- data.frame(v4=factor(rep(c("a", "b"), 500)))
         sparsemrdf2 <- data.frame(mr_1=c(1,0,1,1,0, rep(NA, 995)),
                            mr_2=c(rep(NA, 995), 0, 1, 1, 1, 0),
@@ -217,7 +219,7 @@ if (run.integration.tests) {
                     expect_identical(as.vector(out$CA$mr_2),
                         factor(c(rep(NA, 1995), "0.0", "1.0", "1.0", "1.0", "0.0")))
                 })
-                
+
                 test_that("Rolling back to initial import reverts the append", {
                     out <- restoreVersion(out, length(versions(out))) ## Get the oldest
                     expect_identical(nrow(out), 1000L)
@@ -225,7 +227,7 @@ if (run.integration.tests) {
                 })
             })
         })
-        
+
         with(test.dataset(mrdf, "part1"), {
             part1 <- mrdf.setup(part1, selections="1.0")
             names(subvariables(part1$MR)) <- c("One", "Two", "Three")
@@ -235,8 +237,9 @@ if (run.integration.tests) {
                 names(subvariables(part2$MR)) <- c("Loneliest", "Two", "Three")
                 aliases(subvariables(part2$MR))[3] <- "alt"
                 ## Aliases are c("mr_1", "mr_2", "alt")
-                out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("alias and name matching on appending arrays", {
+                    expect_message(out <- appendDataset(part1, part2),
+                        "No conflicts")
                     expect_that(out, is_not_an_error())
                     expect_true(is.dataset(out))
                     expect_identical(length(batches(out)), 3L)
@@ -249,38 +252,38 @@ if (run.integration.tests) {
                 })
             })
         })
-        
+
         with(test.dataset(newDatasetFromFixture("apidocs")), as="part1", {
             test_that("Setup for testing references post append", {
                 expect_true(name(part1$allpets) == "All pets owned")
                 name(part1$allpets) <- "Some of my pets"
                 expect_true(name(part1$allpets) == "Some of my pets")
             })
-            
+
             ## Release and re-lease
             .releaseDataset(part1)
             part1 <- refresh(part1)
-            
+
             test_that("Check again", {
                 expect_true(name(part1$allpets) == "Some of my pets")
             })
-            
+
             with(test.dataset(newDatasetFromFixture("apidocs")), as="part2", {
                 out <- suppressMessages(try(appendDataset(part1, part2)))
                 test_that("Append doesn't revert metadata changes", {
                     expect_false(name(out$allpets) == "All pets owned")
                     expect_true(name(out$allpets) == "Some of my pets")
                 })
-                                
+
                 ## Release and re-lease
                 .releaseDataset(out)
                 out <- refresh(out)
-                
+
                 test_that("Metadata sticks after releasing", {
                     expect_false(name(out$allpets) == "All pets owned")
                     expect_true(name(out$allpets) == "Some of my pets")
                 })
-                
+
                 ## Change the name and release again
                 name(out$allpets) <- "Apple"
                 .releaseDataset(out)
@@ -292,4 +295,4 @@ if (run.integration.tests) {
             })
         })
     })
-}
\ No newline at end of file
+}
