@@ -1,10 +1,10 @@
 context("Getting values to make local R objects")
 
-ca.values <- structure(c(2L, 2L, 1L, NA, 1L, 2L, 1L, 2L, 2L, 2L, NA, 2L, NA, 
-NA, 1L, 1L, 2L, 2L, 2L, 1L, NA, 1L, NA, NA, 1L, 1L, 1L, 2L, NA, 
-NA, NA, NA, 1L, 2L, NA, NA, 1L, NA, NA, NA, 1L, 2L, 1L, 1L, 1L, 
-NA, 1L, NA, 1L, 2L, 1L, NA, 1L, 2L, NA, 1L, 2L, NA, 1L, NA, 2L, 
-1L, 1L, 2L, 1L, 1L, 2L, 1L, NA, 1L, 2L, 1L, 1L, 1L, 2L), .Dim = c(25L, 
+ca.values <- structure(c(2L, 2L, 1L, NA, 1L, 2L, 1L, 2L, 2L, 2L, NA, 2L, NA,
+NA, 1L, 1L, 2L, 2L, 2L, 1L, NA, 1L, NA, NA, 1L, 1L, 1L, 2L, NA,
+NA, NA, NA, 1L, 2L, NA, NA, 1L, NA, NA, NA, 1L, 2L, 1L, 1L, 1L,
+NA, 1L, NA, 1L, 2L, 1L, NA, 1L, 2L, NA, 1L, 2L, NA, 1L, NA, 2L,
+1L, 1L, 2L, 1L, 1L, 2L, 1L, NA, 1L, 2L, 1L, 1L, 1L, 2L), .Dim = c(25L,
 3L), levels=c("A", "B"), class="factor")
 
 with(fake.HTTP, {
@@ -17,13 +17,13 @@ with(fake.HTTP, {
         expect_identical(names(test.ds),
             c("birthyr", "gender", "textVar", "starttime", "catarray"))
     })
-    
+
     test_that("as.vector on Variables", {
         expect_true(is.numeric(as.vector(test.ds$birthyr)))
         expect_true(is.factor(as.vector(test.ds$gender)))
         expect_true(all(levels(as.vector(test.ds$gender)) %in% names(categories(test.ds$gender))))
     })
-    
+
     test_that("as.vector on Categorical Array", {
         expect_true(is.CA(test.ds$catarray))
         expect_true(is.matrix(as.vector(test.ds$catarray)))
@@ -36,30 +36,30 @@ with(fake.HTTP, {
         expect_identical(dim(as.data.frame(test.ds)), c(25L, ncol(test.ds)))
         expect_identical(names(as.data.frame(test.ds)), names(test.ds))
         expect_identical(as.data.frame(test.ds)$birthyr, as.vector(test.ds$birthyr))
-        expect_identical(evalq(gender, as.data.frame(test.ds)), 
+        expect_identical(evalq(gender, as.data.frame(test.ds)),
             as.vector(test.ds$gender))
     })
-    
+
     test_that("as.data.frame(as.data.frame())", {
         expect_true(is.data.frame(as.data.frame(as.data.frame(test.ds))))
         expect_true(is.data.frame(as.data.frame(test.ds, force=TRUE)))
     })
-    
+
     test_that("as.data.frame size limit", {
         options(crunch.data.frame.limit=50)
-            expect_error(as.data.frame(test.ds, force=TRUE), 
+            expect_error(as.data.frame(test.ds, force=TRUE),
                 "Dataset too large to coerce")
             expect_true(is.data.frame(as.data.frame(test.ds[,1:2], force=TRUE)))
         options(crunch.data.frame.limit=10000)
     })
-    
+
     test.df <- as.data.frame(test.ds)
-    
+
     test_that("model.frame thus works on CrunchDataset", {
         expect_identical(model.frame(birthyr ~ gender, data=test.df),
             model.frame(birthyr ~ gender, data=test.ds))
     })
-    
+
     test_that("so lm() should work too", {
         test.lm <- lm(birthyr ~ gender, data=test.ds)
         expected <- lm(birthyr ~ gender, data=test.df)
@@ -73,7 +73,7 @@ with(fake.HTTP, {
 
 if (run.integration.tests) {
     with(test.authentication, {
-        with(test.dataset(df), {        
+        with(test.dataset(df), {
             test_that("Check the types of our imported data", {
                 expect_true(is.Numeric(ds[["v1"]]))
                 expect_true(is.Text(ds[["v2"]]))
@@ -112,12 +112,12 @@ if (run.integration.tests) {
             })
             ## Delete v4b for the later tests (should just make a fresh ds)
             with(consent(), ds$v4b <- NULL)
-            
+
             test_that("as.vector on Datetime", {
                 expect_true(inherits(as.vector(ds$v5), "Date"))
                 expect_equivalent(as.vector(ds$v5), df$v5)
             })
-        
+
             test_that("as.data.frame with API", {
                 expect_false(is.data.frame(as.data.frame(ds)))
                 expect_true(inherits(as.data.frame(ds), "CrunchDataFrame"))
@@ -126,12 +126,12 @@ if (run.integration.tests) {
                 expect_identical(as.data.frame(ds)$v1,
                     as.vector(ds$v1))
             })
-            
+
             test_that("as.data.frame(force) with API", {
                 expect_true(is.data.frame(as.data.frame(as.data.frame(ds))))
                 expect_true(is.data.frame(as.data.frame(ds, force=TRUE)))
             })
-            
+
             v2 <- ds$v2
             delete(v2)
             test_that("CrunchDataFrame lazily fetches columns", {
@@ -140,13 +140,13 @@ if (run.integration.tests) {
                 ## This should error because it will try to get values for v2
                 expect_error(as.data.frame(ds, force=TRUE))
             })
-        
+
             test_that("model.frame thus works on CrunchDataset over API", {
                 ## would like this to be "identical" instead of "equivalent"
                 expect_equivalent(model.frame(v1 ~ v3, data=ds),
                     model.frame(v1 ~ v3, data=df))
             })
-        
+
             test_that("so lm() should work too over the API", {
                 test.lm <- lm(v1 ~ v3, data=ds)
                 expected <- lm(v1 ~ v3, data=df)
@@ -157,7 +157,25 @@ if (run.integration.tests) {
                     expect_equivalent(test.lm[[i]], expected[[i]])
                 }
             })
+
+            with(no.cache(), {
+                clearCache() ## So we're totally fresh
+                with(temp.options(crunch.page.size=5, crunch.log=""), {
+                    avlog <- capture.output(v1 <- as.vector(ds$v1))
+                    test_that("getValues can be paginated", {
+                        logdf <- loadLogfile(textConnection(avlog))
+                        reqdf <- requestsFromLog(logdf)
+                        ## GET entity to get /values/ URL, then GET /values/ 4x
+                        ## to get data, then a 5th GET /values/ that returns 0
+                        ## values, which breaks the pagination loop
+                        expect_identical(reqdf$verb, rep("GET", 6))
+                        expect_identical(grep("values", reqdf$url), 2:6)
+                    })
+                    test_that("getValues returns the same result when paginated", {
+                        expect_equivalent(v1, df$v1)
+                    })
+                })
+            })
         })
     })
 }
-
