@@ -17,7 +17,7 @@ test_that("rollup CrunchExpr from zcl variable", {
     expect_identical(zcl(rollup(x)),
         list(`function`="rollup", args=list(list(variable="test"),
             list(value=NULL))))
-    
+
     expect_true(inherits(rollup(x, resolution="Y"), "CrunchExpr"))
     expect_identical(zcl(rollup(x, resolution="Y")),
         list(`function`="rollup", args=list(list(variable="test"),
@@ -31,23 +31,26 @@ with(fake.HTTP, {
     test_that("rollup CrunchExpr from DatetimeVariable", {
         expect_true(inherits(rollup(v), "CrunchExpr"))
         expect_identical(zcl(rollup(v)),
-            list(`function`="rollup", args=list(list(variable="d7c21314ca9e453c93069168681a285c"),
+            list(`function`="rollup",
+                args=list(list(variable="/api/datasets/dataset1/variables/starttime.json"),
                 list(value="s"))))
         expect_true(inherits(rollup(v, resolution="Y"), "CrunchExpr"))
         expect_identical(zcl(rollup(v, resolution="Y")),
-            list(`function`="rollup", args=list(list(variable="d7c21314ca9e453c93069168681a285c"),
+            list(`function`="rollup",
+                args=list(list(variable="/api/datasets/dataset1/variables/starttime.json"),
                 list(value="Y"))))
         expect_true(inherits(rollup(v, resolution=NULL), "CrunchExpr"))
         expect_identical(zcl(rollup(v, resolution=NULL)),
-            list(`function`="rollup", args=list(list(variable="d7c21314ca9e453c93069168681a285c"),
+            list(`function`="rollup",
+                args=list(list(variable="/api/datasets/dataset1/variables/starttime.json"),
                 list(value=NULL))))
     })
 })
 
 test_that("rollup resolution validation", {
-    expect_error(rollup("a", resolution="Invalid"), 
+    expect_error(rollup("a", resolution="Invalid"),
         " is invalid. Valid values are NULL, ")
-    expect_error(rollup("a", resolution=42), 
+    expect_error(rollup("a", resolution=42),
         " is invalid. Valid values are NULL, ")
 })
 
@@ -57,8 +60,8 @@ adims <- CubeDims(list(
     v7=list(name=c("C", "D", "E", "No Data"), any.or.none=rep(FALSE, 4),
         missing=c(rep(FALSE, 3), TRUE))))
 a1 <- CrunchCube(arrays=list("count"=array(c(
-        8, 6, 
-        3, 2, 
+        8, 6,
+        3, 2,
         2, 3,
         0, 0), dim=c(2L, 4L))),
     dims=adims)
@@ -71,7 +74,7 @@ test_that("simple margin.table", {
     expect_equivalent(margin.table(a1, 1), margin.table(a1@arrays[[1]], 1))
     expect_identical(margin.table(a1, 1),
         array(c(13, 11), dim=2L, dimnames=list(v4=c("B", "C"))))
-    expect_identical(margin.table(a1, 2), 
+    expect_identical(margin.table(a1, 2),
         array(c(14, 5, 5), dim=3L, dimnames=list(v7=LETTERS[3:5])))
     expect_equivalent(margin.table(a1), margin.table(a1@arrays[[1]]))
     expect_identical(margin.table(a1), 24)
@@ -82,7 +85,7 @@ test_that("margin.table with any/none", {
     a2@dims[[2]]$any.or.none[1] <- TRUE ## "C"
     expect_identical(margin.table(a2, 1),
         array(c(8, 6), dim=2L, dimnames=list(v4=c("B", "C"))))
-    expect_identical(margin.table(a2, 2), 
+    expect_identical(margin.table(a2, 2),
         array(c(5, 5), dim=2L, dimnames=list(v7=LETTERS[4:5])))
     expect_identical(margin.table(a2), 14)
 })
@@ -93,23 +96,23 @@ test_that("margin.table with missing", {
     expect_identical(a2@useNA, "no") ## The default.
     expect_identical(margin.table(a2, 1),
         array(c(10, 9), dim=2L, dimnames=list(v4=c("B", "C"))))
-    expect_identical(margin.table(a2, 2), 
+    expect_identical(margin.table(a2, 2),
         array(c(14, 5), dim=2L, dimnames=list(v7=c("C", "E"))))
     expect_identical(margin.table(a2), 19)
-    
+
     a2@useNA <- "ifany"
     ## Should be the same as first tests
     expect_identical(margin.table(a2, 1),
         array(c(13, 11), dim=2L, dimnames=list(v4=c("B", "C"))))
-    expect_identical(margin.table(a2, 2), 
+    expect_identical(margin.table(a2, 2),
         array(c(14, 5, 5), dim=3L, dimnames=list(v7=LETTERS[3:5])))
     expect_identical(margin.table(a2), 24)
-    
+
     a2@useNA <- "always"
     expect_identical(margin.table(a2, 1),
         array(c(13, 11), dim=2L, dimnames=list(v4=c("B", "C"))))
-    expect_identical(margin.table(a2, 2), 
-        array(c(14, 5, 5, 0), dim=4L, 
+    expect_identical(margin.table(a2, 2),
+        array(c(14, 5, 5, 0), dim=4L,
             dimnames=list(v7=c(LETTERS[3:5], "No Data"))))
     expect_identical(margin.table(a2), 24)
 })
@@ -118,7 +121,7 @@ if (run.integration.tests) {
     with(test.authentication, {
         with(test.dataset(cubedf), {
             test_that("cubedf setup", {
-                expect_identical(names(categories(ds$v7)), 
+                expect_identical(names(categories(ds$v7)),
                     c("C", "D", "E", "No Data"))
             })
             test_that("We can get a univariate categorical cube", {
@@ -129,7 +132,7 @@ if (run.integration.tests) {
                         dimnames=list(v7=LETTERS[3:5])))
                 ## Not sure why not identical, str makes them look the same
             })
-            
+
             test_that("We can get a bivariate categorical cube", {
                 kube <- try(crtabs(~ v4 + v7, data=ds))
                 expect_true(inherits(kube, "CrunchCube"))
@@ -137,7 +140,7 @@ if (run.integration.tests) {
                     array(c(5, 5, 3, 2, 2, 3), dim=c(2L, 3L),
                         dimnames=list(v4=c("B", "C"), v7=LETTERS[3:5])))
             })
-            
+
             is.na(categories(ds$v7)) <- "D"
             test_that("useNA on univariate cube", {
                 expect_equivalent(as.array(crtabs(~ v7, data=ds)),
@@ -161,14 +164,14 @@ if (run.integration.tests) {
                         dimnames=list(v4=c("B", "C"), v7=LETTERS[3:5])))
                 expect_equivalent(as.array(crtabs(~ v4 + v7, data=ds,
                     useNA="always")),
-                    array(c(5, 5, 0, 
-                            3, 2, 0, 
-                            2, 3, 0, 
+                    array(c(5, 5, 0,
+                            3, 2, 0,
+                            2, 3, 0,
                             0, 0, 0), dim=c(3L, 4L),
                         dimnames=list(v4=c("B", "C", "No Data"),
                                     v7=c(LETTERS[3:5], "No Data"))))
             })
-            
+
             test_that("univariate datetime cube", {
                 kube <- try(crtabs(~ v8, data=ds))
                 expect_true(inherits(kube, "CrunchCube"))
@@ -184,24 +187,24 @@ if (run.integration.tests) {
                 expect_equivalent(as.array(crtabs(~ v8 + v7, data=ds,
                     useNA="ifany")),
                     array(c(5, 5, 3, 2, 2, 3), dim=c(2L, 3L),
-                        dimnames=list(v8=c("1955-11-05", "1955-11-06"), 
+                        dimnames=list(v8=c("1955-11-05", "1955-11-06"),
                         v7=LETTERS[3:5])))
                 expect_equivalent(as.array(crtabs(~ v8 + v7, data=ds,
                     useNA="always")),
-                    array(c(5, 5, 
-                            3, 2, 
-                            2, 3, 
+                    array(c(5, 5,
+                            3, 2,
+                            2, 3,
                             0, 0), dim=c(2L, 4L),
-                        dimnames=list(v8=c("1955-11-05", "1955-11-06"), 
+                        dimnames=list(v8=c("1955-11-05", "1955-11-06"),
                         v7=c(LETTERS[3:5], "No Data"))))
             })
-            
+
             test_that("datetime rollup cubes", {
                 ## Default rollup resolution for this should be same as
                 ## its resolution, given the date range
                 expect_equivalent(as.array(crtabs(~ rollup(v8) + v7,
                     data=ds)),
-                    as.array(crtabs(~ v8 + v7, data=ds))) 
+                    as.array(crtabs(~ v8 + v7, data=ds)))
                 expect_equivalent(as.array(crtabs(~ rollup(v8, "M") + v7,
                     data=ds)),
                     array(c(10, 5), dim=c(1L, 2L),
@@ -213,7 +216,7 @@ if (run.integration.tests) {
                         dimnames=list(v8=c("1955"),
                         v7=c("C", "E"))))
             })
-            
+
             test_that("univariate cube with binned numeric", {
                 kube <- try(crtabs(~ bin(v3), data=ds))
                 expect_true(inherits(kube, "CrunchCube"))
@@ -235,7 +238,7 @@ if (run.integration.tests) {
                             0, 0, 2, 3, 0,
                             0, 0, 0, 2, 3), dim=c(5L, 3L),
                         dimnames=list(v3=c("5-10", "10-15", "15-20", "20-25",
-                        "25-30"), 
+                        "25-30"),
                         v7=LETTERS[3:5])))
                 expect_equivalent(as.array(crtabs(~ bin(v3) + v7, data=ds,
                     useNA="always")),
@@ -244,7 +247,7 @@ if (run.integration.tests) {
                             0, 0, 0, 2, 3,
                             0, 0, 0, 0, 0), dim=c(5L, 4L),
                         dimnames=list(v3=c("5-10", "10-15", "15-20", "20-25",
-                        "25-30"), 
+                        "25-30"),
                         v7=c(LETTERS[3:5], "No Data"))))
             })
             test_that("unbinned numeric", {
@@ -255,7 +258,7 @@ if (run.integration.tests) {
                     array(c(rep(1, 15), 5), dim=16L,
                         dimnames=list(v1=c(df$v1[6:20], "<NA>"))))
             })
-            
+
             test_that("Weighted cubes", {
                 weight(ds) <- ds$v3
                 expect_equivalent(as.array(crtabs(~ v8 + v7, data=ds)),
@@ -278,7 +281,7 @@ if (run.integration.tests) {
                         dimnames=list(v8=c("1955-11-05", "1955-11-06"),
                         v7=c("C", "E"))))
             })
-            
+
             test_that("Numeric aggregates", {
                 expect_equivalent(as.array(crtabs(mean(v3) ~ v8 + v7,
                     data=ds)),
@@ -296,7 +299,7 @@ if (run.integration.tests) {
                         dimnames=list(v8=c("1955-11-05", "1955-11-06"),
                         v7=c("C", "E"))))
             })
-            
+
             test_that("Missing values in cubes", {
                 expect_equivalent(round(as.array(crtabs(sd(v3) ~ bin(v3) + v7,
                     data=ds)), 3),
@@ -306,7 +309,7 @@ if (run.integration.tests) {
                         "25-30"),
                         v7=c("C", "E"))))
             })
-            
+
             test_that("round cubes", {
                 expect_equivalent(round(crtabs(sd(v3) ~ bin(v3) + v7,
                     data=ds), 3),
@@ -316,7 +319,7 @@ if (run.integration.tests) {
                         "25-30"),
                         v7=c("C", "E"))))
             })
-            
+
             test_that("Cube with variables and R objects", {
                 skip("(400) Bad Request: No such category id: '1'.")
                 d4 <- cubedf$v4
@@ -324,21 +327,21 @@ if (run.integration.tests) {
                     array(c(5, 5, 2, 3), dim=c(2L, 2L),
                         dimnames=list(v4=c("B", "C"), v7=c("C", "E"))))
             })
-            
+
             test_that("Cube with transformations", {
                 expect_equivalent(as.array(crtabs(~ bin(v3 + 5), data=ds)),
                     array(c(2, 5, 5, 5, 3), dim=c(5L),
                         dimnames=list(v3=c("10-15", "15-20", "20-25",
                         "25-30", "30-35"))))
             })
-            
+
             test_that("prop.table on univariate cube", {
                 expect_equivalent(prop.table(crtabs(~ bin(v3 + 5), data=ds)),
                     array(c(2, 5, 5, 5, 3)/20, dim=c(5L),
                         dimnames=list(v3=c("10-15", "15-20", "20-25",
                         "25-30", "30-35"))))
             })
-            
+
             test_that("prop.table on crosstab", {
                 expect_equivalent(prop.table(crtabs(~ bin(v3) + v7, data=ds)),
                     array(c(2, 5, 3, 0, 0,
@@ -361,7 +364,7 @@ if (run.integration.tests) {
                         "25-30"),
                         v7=c("C", "E"))))
             })
-            
+
             test_that("Univariate stats", {
                 expect_equivalent(as.array(crtabs(mean(v3) ~ 1, data=ds)),
                     17.5)
