@@ -1,27 +1,27 @@
-context("Dataset object and methods") 
+context("Dataset object and methods")
 
 with(fake.HTTP, {
     test.ds <- loadDataset("test ds")
-    
+
     test_that("Dataset can be created", {
         expect_true(is.dataset(test.ds))
     })
-    
+
     test_that("Dataset attributes", {
         expect_identical(name(test.ds), "test ds")
         expect_identical(description(test.ds), "")
         expect_identical(id(test.ds), "511a7c49778030653aab5963")
     })
-    
+
     test_that("Dataset webURL", {
         with(temp.options(crunch.api="https://fake.crunch.io/api/v2/"), {
             expect_identical(webURL(test.ds),
                 "https://fake.crunch.io/dataset/511a7c49778030653aab5963")
         })
     })
-    
+
     test_that("Dataset VariableCatalog index is sorted", {
-        expect_identical(urls(allVariables(test.ds)), 
+        expect_identical(urls(allVariables(test.ds)),
             c("/api/datasets/dataset1/variables/birthyr.json",
             "/api/datasets/dataset1/variables/catarray.json",
             "/api/datasets/dataset1/variables/gender.json",
@@ -40,11 +40,11 @@ with(fake.HTTP, {
     test_that("useAlias exists and affects names()", {
         thisds <- test.ds
         expect_true(thisds@useAlias)
-        expect_identical(names(thisds), 
+        expect_identical(names(thisds),
             findVariables(thisds, key="alias", value=TRUE))
         thisds@useAlias <- FALSE
         expect_false(thisds@useAlias)
-        expect_identical(names(thisds), 
+        expect_identical(names(thisds),
             findVariables(thisds, key="name", value=TRUE))
     })
 
@@ -72,13 +72,14 @@ with(fake.HTTP, {
         expect_identical(test.ds$not.a.var.name, NULL)
         expect_error(test.ds[[999]], "subscript out of bounds")
     })
-    
+
     test_that("Dataset extract error handling", {
         expect_error(test.ds[[999]], "subscript out of bounds")
         expect_error(test.ds[c("gender", "NOTAVARIABLE")],
             "Undefined columns selected: NOTAVARIABLE")
+        expect_true(is.null(test.ds$name))
     })
-    
+
     test_that("Extract from dataset by VariableOrder/Group", {
         ents <- c("/api/datasets/dataset1/variables/gender.json",
             "/api/datasets/dataset1/variables/mymrset.json")
@@ -103,9 +104,9 @@ with(fake.HTTP, {
         expect_false(identical(description(dataset), description(test.ds)))
         expect_identical(description(dataset), "007")
     })
-    
+
     test_that("show method", {
-        expect_identical(getShowContent(test.ds), 
+        expect_identical(getShowContent(test.ds),
             c(paste("Dataset", dQuote("test ds")),
             "",
             "Contains 25 rows of 6 variables:",
@@ -117,7 +118,7 @@ with(fake.HTTP, {
             "$catarray: Cat Array (categorical_array)"
         ))
     })
-    
+
     test_that("dataset can refresh", {
         ds <- loadDataset("test ds")
         expect_identical(ds, refresh(ds))
@@ -132,18 +133,22 @@ if (run.integration.tests) {
                 name(ds) <- "Bond. James Bond."
                 expect_identical(name(refresh(d2)), name(ds))
             })
-        })
-        test_that("Name and description setters don't push to server if readonly", {
 
+            test_that("A variable named/aliased 'name' can be accessed", {
+                ds$name <- 1
+                expect_true("name" %in% aliases(variables(ds)))
+                expect_true("name" %in% names(ds))
+                expect_true(is.Numeric(ds$name))
+            })
         })
-        
+
         with(test.dataset(df), {
             test_that("dataset dim", {
                 expect_identical(dim(ds), dim(df))
                 expect_identical(nrow(ds), nrow(df))
                 expect_identical(ncol(ds), ncol(df))
             })
-            
+
             test_that("refresh keeps useAlias setting", {
                 expect_true(ds@useAlias)
                 expect_true(refresh(ds)@useAlias)
@@ -151,13 +156,13 @@ if (run.integration.tests) {
                 expect_false(ds@useAlias)
                 expect_false(refresh(ds)@useAlias)
             })
-            
+
             test_that("Dataset [[<-", {
                 v1 <- ds$v1
                 name(v1) <- "Variable One"
                 ds$v1 <- v1
                 expect_identical(names(variables(ds))[1], "Variable One")
-                expect_error(ds$v2 <- v1, 
+                expect_error(ds$v2 <- v1,
                     "Cannot overwrite one Variable")
             })
         })
@@ -165,39 +170,39 @@ if (run.integration.tests) {
         with(test.dataset(mrdf), {
             cast.these <- grep("mr_", names(ds))
             test_that("Dataset [<-", {
-                expect_true(all(vapply(variables(ds)[cast.these], 
+                expect_true(all(vapply(variables(ds)[cast.these],
                     function (x) x$type == "numeric", logical(1))))
-                expect_true(all(vapply(ds[cast.these], 
+                expect_true(all(vapply(ds[cast.these],
                     function (x) is.Numeric(x), logical(1))))
                 ds[cast.these] <- lapply(ds[cast.these],
                     castVariable, "categorical")
-                expect_true(all(vapply(variables(ds)[cast.these], 
+                expect_true(all(vapply(variables(ds)[cast.these],
                     function (x) x$type == "categorical", logical(1))))
-                expect_true(all(vapply(ds[cast.these], 
+                expect_true(all(vapply(ds[cast.these],
                     function (x) is.Categorical(x), logical(1))))
             })
             test_that("Dataset [[<- on new array variable", {
-                try(ds$arrayVar <- makeArray(ds[cast.these], 
+                try(ds$arrayVar <- makeArray(ds[cast.these],
                     name="Array variable"))
                 expect_true(is.CA(ds$arrayVar))
                 expect_identical(name(ds$arrayVar), "Array variable")
             })
         })
-        
+
         test_that("Dataset deleting is safe", {
             with(test.dataset(df), {
-                expect_error(delete(ds, confirm=TRUE), 
+                expect_error(delete(ds, confirm=TRUE),
                     "Must confirm deleting dataset")
                 ds.sub <- ds[1]
                 expect_true(is.dataset(ds.sub))
                 expect_true(is.readonly(ds.sub))
-                expect_error(delete(ds.sub), 
+                expect_error(delete(ds.sub),
                     "Must confirm deleting dataset")
                 ## Then can delete
                 expect_that(delete(ds.sub, confirm=FALSE), is_not_an_error())
             })
         })
-        
+
         test_that("Can give consent to delete", {
             with(test.dataset(df), {
                 with(consent(), {
@@ -206,4 +211,4 @@ if (run.integration.tests) {
             })
         })
     })
-}
\ No newline at end of file
+}
