@@ -3,28 +3,28 @@ context("Variable catalog")
 with(fake.HTTP, {
     variables.catalog.url <- "/api/datasets/dataset1/variables.json"
     varblob <- crGET(variables.catalog.url)
-    
+
     test_that("VariableCatalog instantiates from Shoji", {
         expect_true(inherits(VariableCatalog(varblob),
             "VariableCatalog"))
     })
-    
+
     varcat <- VariableCatalog(varblob)
     order.url <- "/api/datasets/dataset1/variables/hierarchical.json"
     varorder <- VariableOrder(crGET(order.url))
-    
+
     test_that("VariableCatalog index method", {
         expect_identical(names(index(varcat)), names(varcat@index))
         expect_identical(names(index(varcat)), names(varblob$index))
     })
-    
+
     test_that("VariableCatalog has the right contents", {
         expect_true(all(grepl("/api/datasets/dataset1/variables",
             urls(varcat))))
         expect_identical(self(varcat), variables.catalog.url)
         expect_identical(entities(ordering(varcat)), entities(varorder))
     })
-    
+
     test_that("active/hidden getters", {
         expect_identical(index(active(varcat)),
             index(varcat)[urls(ordering(varcat))])
@@ -32,7 +32,7 @@ with(fake.HTTP, {
         index(varcat)[[2]]$discarded <- TRUE
         expect_true(inherits(active(varcat), "VariableCatalog"))
         expect_true(inherits(hidden(varcat), "VariableCatalog"))
-        expect_identical(urls(active(varcat)), 
+        expect_identical(urls(active(varcat)),
             c("/api/datasets/dataset1/variables/gender.json",
             "/api/datasets/dataset1/variables/mymrset.json",
             "/api/datasets/dataset1/variables/textVar.json",
@@ -45,7 +45,7 @@ with(fake.HTTP, {
         expect_identical(length(varcat), 6L)
         expect_identical(active(hidden(varcat)), hidden(active(varcat)))
     })
-    
+
     gender.url <- "/api/datasets/dataset1/variables/gender.json"
     test_that("Extract methods: character and numeric", {
         expect_true(inherits(varcat[[gender.url]], "VariableTuple"))
@@ -57,7 +57,7 @@ with(fake.HTTP, {
         expect_error(varcat[["asdf"]], "subscript out of bounds")
         expect_error(varcat[999:1000], "subscript out of bounds")
     })
-    
+
     test_that("Extract methods: VariableOrder/Group", {
         ents <- c("/api/datasets/dataset1/variables/gender.json",
             "/api/datasets/dataset1/variables/mymrset.json")
@@ -66,24 +66,29 @@ with(fake.HTTP, {
         expect_identical(varcat[ord[[1]]], varcat[ents])
         expect_identical(varcat[ord], varcat[ents])
     })
-    
+
     test_that("Construct Variable from Tuple", {
         expect_true(is.Categorical(CrunchVariable(varcat[[gender.url]])))
     })
-    
+
     test_that("name and alias getters", {
         expect_identical(names(varcat)[1:3],
             c("Gender", "Birth Year", "starttime"))
         expect_identical(aliases(varcat)[1:2], c("gender", "birthyr"))
     })
-    
+
     test_that("types getter", {
         expect_identical(types(varcat)[1:3],
             c("categorical", "numeric", "datetime"))
     })
-    
+
     test_that("show method", {
-        expect_true(is.character(capture.output(print(varcat))))
+        expect_identical(capture.output(print(varcat[1:3])),
+            capture.output(print(data.frame(
+                alias=c("gender", "birthyr", "starttime"),
+                name=c("Gender", "Birth Year", "starttime"),
+                type=c("categorical", "numeric", "datetime")
+            ))))
     })
 })
 
@@ -93,7 +98,7 @@ if (run.integration.tests) {
             test_that("Can set descriptions", {
                 expect_identical(descriptions(variables(ds)), rep("", ncol(ds)))
                 descriptions(variables(ds))[2:3] <- c("Des 1", "Des 2")
-                expect_identical(descriptions(variables(ds))[1:4], 
+                expect_identical(descriptions(variables(ds))[1:4],
                     c("", "Des 1", "Des 2", ""))
             })
             test_that("Can set names and aliases", {
@@ -111,19 +116,19 @@ if (run.integration.tests) {
                 expect_identical(aliases(variables(ds)), n3)
                 expect_identical(aliases(variables(refresh(ds))), n3)
             })
-            
+
             test_that("Can [<- with VariableGroup/Order", {
                 names(variables(ds))[2:3] <- c("two", "three")
                 ord <- VariableOrder(VariableGroup("a group", entities=ds[2:3]))
-                expect_identical(names(variables(ds)[ord]), 
+                expect_identical(names(variables(ds)[ord]),
                     c("two", "three"))
                 try(names(variables(ds)[ord[[1]]]) <- c("TWO", "Three"))
-                expect_identical(names(variables(ds)[ord]), 
+                expect_identical(names(variables(ds)[ord]),
                     c("TWO", "Three"))
                 try(names(variables(ds)[ord]) <- c("2", "3"))
-                expect_identical(names(variables(ds)[ord]), 
+                expect_identical(names(variables(ds)[ord]),
                     c("2", "3"))
             })
         })
     })
-}
\ No newline at end of file
+}
